// coding: utf-8
/** Created by: Udo Schmal | https://www.gocher.me/ */
(function () {
  'use strict';
  function youtube(el) {
    var player, id;
    // don't send referrer infos to external services
    if (!document.querySelector('meta[name="referrer"]')) {
      let meta = document.createElement('meta');
      meta.name = 'referrer';
      meta.content = 'no-referrer';
      document.head.appendChild(meta);
    }
    // get YouTube video id
    if (el.dataset.src && el.dataset.src.length === 11) {
      id = el.dataset.src;
    } else {
      let src = el.dataset.src;
      let regExp = /^.*((youtube\/)|(v\/)|(\/u\/\w\/)|(embed\/)|(watch\?))\??v?=?([^#&?]*).*/;
      let match = src.match(regExp);
      id = (match && match[7].length == 11) ? match[7] : src;
    }
    el.id = id;
    // show in popup, other defined target or replace el with player
    var target = el.dataset.target || id;

    // create placeholder background image
    if (el.dataset.poster) {
      el.style.backgroundImage = "url('" + el.dataset.poster + "')";
    } else {
      // high quality: https://img.youtube.com/vi/<insert-youtube-video-id-here>/hqdefault.jpg
      // medium quality: https://img.youtube.com/vi/<insert-youtube-video-id-here>/mqdefault.jpg
      // standard quality: https://img.youtube.com/vi/<insert-youtube-video-id-here>/sddefault.jpg
      // maximum resolution: https://img.youtube.com/vi/<insert-youtube-video-id-here>/maxresdefault.jpg
      //el.style.backgroundImage = "url('https://i.ytimg.com/vi_webp/" + id + "/sddefault.webp')"; // not supported by IE11
      el.style.backgroundImage = "url('https://img.youtube.com/vi/" + id + "/sddefault.jpg')";
    }
    // show placeholder title
    if (el.title) {
      let title = document.createElement('div');
      title.className = 'title';
      title.appendChild(document.createTextNode(el.title));
      el.appendChild(title);
    }
    // show placeholder external message
    if (el.dataset.external) {
      let external = document.createElement('div');
      external.className = 'external';
      let language = window.navigator.userLanguage || window.navigator.language;
      if (!language) {
        language = 'en';
      }
      let txt;
      switch (language.substr(0,2)) {
        case 'de': txt = 'Lädt externe Inhalte von YouTube'; break;
        case 'fr': txt = 'Charger du contenu externe à partir de YouTube'; break;
        case 'it': txt = 'Carica contenuti esterni da YouTube'; break;
        case 'es': txt = 'Cargar contenido externo de YouTube'; break;
        default: txt = 'Load external Content from YouTube'; break;
      }
      external.appendChild(document.createTextNode(txt));
      el.appendChild(external);
    }
    // show placeholder youtube like play button
    var play = document.createElement('div');
    play.className = 'play';
    el.appendChild(play);

    // create popup
    function createPopup() {
      var overlay = document.createElement('div');
      overlay.className = 'overlay';
      document.body.appendChild(overlay);
      var content = document.createElement('div');
      content.className = 'popup-content';
      content.id = 'popup-content';
      overlay.appendChild(content);
      var close = document.createElement('span');
      close.className = 'popup-close';
      overlay.appendChild(close);
      close.addEventListener('click', function (event) {
        player.stopVideo();
        document.body.removeChild(overlay);
      });
      return content.id;
    }
    // youtube player API
    function onPlayerReady(event) {
      event.target.playVideo();
    }
    function onPlayerStateChange(event) {
      if (event.data == window.YT.PlayerState.ENDED) {
        player.stopVideo();
        document.body.removeChild(overlay);
      }
    }
    // create youtube player
    function createPlayer() {
      window.YT.ready(function() {
        var dest, obj = {
          videoId: id,
          host: 'https://www.youtube-nocookie.com',
          events: {
            'onReady': onPlayerReady
          }
        };
        var sizes = [
          { width: '426', height: '240' },
          { width: '640', height: '360' },
          { width: '854', height: '480' },
          { width: '1280', height: '720' },
          { width: '1920', height: '1080' }
        ];
        if (target == 'popup') {
          dest = createPopup();
          obj.events['onStateChange'] = onPlayerStateChange;
          for(var i = 0; i < sizes.length; i++) {
            if (sizes[i].width <= window.innerWidth) {
              obj.height = sizes[i].height;
              obj.width = sizes[i].width;
            } else {
              break;
            }
          }
        } else {
          dest = target;
          for(var i = 0; i < sizes.length; i++) {
            if (sizes[i].width >= el.offsetWidth) {
              obj.height = sizes[i].height;
              obj.width = sizes[i].width;
              break;
            }
          }
        }
        // create YouTube player
        player = new window.YT.Player(dest, obj);
      });
    }
    // load youtube external content
    function load() {
      // init once
      if (!document.getElementById('YouTubeApi')) {
        // load YouTube API
        var script = document.createElement('script');
        script.id = 'YouTubeApi';
        script.src = 'https://www.youtube.com/iframe_api';
        document.head.appendChild(script);
        script.addEventListener('load', createPlayer);
      } else {
        createPlayer();
      }
      if (target !== 'popup') {
        // remove placeholder click event
        play.removeEventListener('click', load);
      }
    }
    play.addEventListener('click', load);
  }

  var media = document.querySelectorAll('.youtube[data-src]');
  for (let i=0; i < media.length; i++) {
    new youtube(media[i]);
  }
})();
